@@ -2,11 +2,10 @@
 #' 
 #' \code{check_sels} checks whether selections can be read by subsequent functions.
 #' @usage check_sels(X, parallel = 1, path = NULL, check.header = FALSE, pb = TRUE,
-#' wav.size = FALSE, verbose = TRUE)
+#' wav.size = FALSE, verbose = TRUE, fix.selec = FALSE)
 #' @param X 'selection_table' object or data frame with the following columns: 1) "sound.files": name of the .wav 
 #' files, 2) "sel": number of the selections, 3) "start": start time of selections, 4) "end": 
-#' end time of selections. Alternatively, a 'selection_table' class object can be input to double check selections. The output of \code{\link{auto_detec}} can 
-#' be used as the input data frame.
+#' end time of selections. Alternatively, a 'selection_table' class object can be input to double check selections.
 #' @param parallel Numeric. Controls whether parallel computing is applied.
 #'  It specifies the number of cores to be used. Default is 1 (i.e. no parallel computing).
 #' @param path Character string containing the directory path where the sound files are located. 
@@ -18,7 +17,8 @@
 #' @param wav.size Logical argument to control if the size of the wave object 
 #'  when the selection is imported into R (as when using \code{\link[tuneR]{readWave}}
 #'  is calculated and added as a column. Size is return in MB. Default is \code{FALSE}.
-#' @param verbose Logical to control whether the 'path' is printed in the console. Defaut is \code{TRUE}.
+#' @param verbose Logical to control whether the summary messages are printed to the console. Defaut is \code{TRUE}.
+#' @param fix.selec Logical to control if labels in 'selec' column should be fixed. This column should not be duplicated within a sound file. If that happens and \code{fix.selec = TRUE} duplicated labels will be changed. Default is \code{FALSE}.  
 #' @return A data frame including the columns in the input data frame (X) and the following additional columns:
 #' \itemize{
 #'    \item \code{check.res}: diagnose for each selection 
@@ -35,7 +35,7 @@
 #' \itemize{
 #'    \item 'X' is an object of class 'data.frame' or 'selection_table' (see \code{\link{selection_table}}) and contains 
 #'    the required columns to be used on any warbleR function ('sound.files', 'selec', 'start', 'end', if not returns an error) 
-#'    \item  'sound.files' in 'X' correspond to .wav files in the working directory or in the provided 'path'
+#'    \item  'sound.files' in 'X' correspond to sound files in the working directory or in the provided 'path'
 #'     (if no file is found returns an error, if some files are not found returns error info in the ouput data frame)
 #'    \item time ('start', 'end') and frequency ('bottom.freq', 'top.freq', if provided) limit parameters are numeric and 
 #'    don't contain NAs (if not returns an error)
@@ -72,10 +72,7 @@
 #last modification on jul-5-2016 (MAS)
 
 check_sels <- function(X = NULL, parallel =  1, path = NULL, check.header = FALSE, 
-                      pb = TRUE, wav.size = FALSE, verbose = TRUE){
-  
-  # reset pbapply pb
-  on.exit(pbapply::pboptions(type = .Options$pboptions$type), add = TRUE)
+                      pb = TRUE, wav.size = FALSE, verbose = TRUE, fix.selec = FALSE){
   
   #### set arguments from options
   # get function arguments
@@ -84,9 +81,6 @@ check_sels <- function(X = NULL, parallel =  1, path = NULL, check.header = FALS
   # get warbleR options
   opt.argms <- if(!is.null(getOption("warbleR"))) getOption("warbleR") else SILLYNAME <- 0
   
-  # rename path for sound files
-  names(opt.argms)[names(opt.argms) == "wav.path"] <- "path"
-  
   # remove options not as default in call and not in function arguments
   opt.argms <- opt.argms[!sapply(opt.argms, is.null) & names(opt.argms) %in% argms]
   
@@ -123,8 +117,14 @@ check_sels <- function(X = NULL, parallel =  1, path = NULL, check.header = FALS
   #if there are NAs in start or end stop
   if (any(is.na(c(X$end, X$start)))) stop("NAs found in start and/or end")  
   
-  # check for duplicates
-  if (any(duplicated(paste(X$sound.files, X$selec)))) stop("Duplicated selection labels for one or more sound files")
+  # check for duplicates and if fix.selec = TRUE
+  if (any(duplicated(paste(X$sound.files, X$selec)))) 
+    if (fix.selec) {
+      
+      X$selec <- do.call(c, lapply(unique(X$sound.files), function(x) seq_len(sum(X$sound.files == x))))
+      
+    } else
+    stop("Duplicated selection labels ('selec' column) for one or more sound files (can be fixed by setting fix.selec = TRUE)")
   
   #check additional columns
   if (!"channel" %in% colnames(X)) 
@@ -139,7 +139,7 @@ check_sels <- function(X = NULL, parallel =  1, path = NULL, check.header = FALS
   #check if files are in working directory
   files <- file.exists(file.path(path, unique(X$sound.files)))
   if (all(!files)) 
-    stop("no .wav files found")
+    stop("no sound files found")
   
   # update to new frequency range column names
   if (any(grepl("low.freq|high.freq", names(X)))) {
@@ -164,14 +164,14 @@ check_sels <- function(X = NULL, parallel =  1, path = NULL, check.header = FALS
     Y <- as.data.frame(X[X$sound.files == x, , drop = FALSE])
     
     if (file.exists(file.path(pth, x))){
-      rec <- try(suppressWarnings(warbleR::read_wave(X= x, path = pth, header = TRUE)), silent = TRUE)
+      rec <- try(suppressWarnings(read_sound_file(X = x, path = pth, header = TRUE)), silent = TRUE)
       
       # if it was read
       if (!is(rec, "try-error"))
       {
         if (check.header) # look for mismatchs between file header & file content  
         {
-          recfull <- try(suppressWarnings(warbleR::read_wave(X = x, path = pth, header = FALSE)), silent = TRUE)
+          recfull <- try(suppressWarnings(read_sound_file(X = x, path = pth, header = FALSE)), silent = TRUE)
           if (any(methods::slotNames(recfull) == "stereo")) 
           {
             if (rec$channels == 2) channel.check <- ifelse(recfull@stereo, FALSE, TRUE) else
@@ -239,15 +239,15 @@ check_sels <- function(X = NULL, parallel =  1, path = NULL, check.header = FALS
     return(Y)
   }
   
-  # set pb options 
-  pbapply::pboptions(type = ifelse(pb, "timer", "none"))
+  
+  
   
   # set clusters for windows OS
   if (Sys.info()[1] == "Windows" & parallel > 1)
     cl <- parallel::makePSOCKcluster(getOption("cl.cores", parallel)) else cl <- parallel
   
   # run loop apply function
-  out <- pbapply::pblapply(X = unique(X$sound.files), cl = cl, FUN = function(x) 
+  out <- pblapply_wrblr_int(pbar = pb, X = unique(X$sound.files), cl = cl, FUN = function(x) 
   { 
     csFUN(x, X, pth = path)
   }) 
