@@ -61,9 +61,6 @@ fix_wavs <- function(checksels = NULL, files = NULL, samp.rate = NULL, bit.depth
   # get warbleR options
   opt.argms <- if(!is.null(getOption("warbleR"))) getOption("warbleR") else SILLYNAME <- 0
   
-  # rename path for sound files
-  names(opt.argms)[names(opt.argms) == "wav.path"] <- "path"
-  
   # remove options not as default in call and not in function arguments
   opt.argms <- opt.argms[!sapply(opt.argms, is.null) & names(opt.argms) %in% argms]
   
@@ -171,7 +168,7 @@ fix_sox_FUN <- function(x)
 
 # fix_FUN <- if (sox)  fix_sox_FUN else fix_bio_FUN 
 
-  out <- pbapply::pblapply(fls, fix_sox_FUN)
+  out <- pblapply_wrblr_int(pbar = TRUE, X = fls, FUN = fix_sox_FUN)
   }
 
 
