@@ -2,14 +2,13 @@
 #' 
 #' \code{freq_ts} extracts the fundamental frequency values as a time series.
 #' @usage freq_ts(X, type = "dominant", wl = 512, length.out = 20, wn = "hanning", 
-#' ovlp = 70, bp = c(0, 22), threshold = 15, img = TRUE, parallel = 1, path = NULL, 
+#' ovlp = 70, bp = NULL, threshold = 15, img = TRUE, parallel = 1, path = NULL, 
 #' img.suffix = "frequency.ts", pb = TRUE, clip.edges = FALSE, leglab = "frequency.ts", 
 #' track.harm = FALSE, raw.contour = FALSE, adjust.wl = TRUE, 
 #' ff.method = "seewave", entropy.range = c(2, 10), ...)
 #' @param X object of class 'selection_table', 'extended_selection_table' or data 
 #' frame containing columns for sound file name (sound.files), 
 #' selection number (selec), and start and end time of signal (start and end).
-#' The output of \code{\link{auto_detec}} can be used as the input data frame.
 #' @param type Character string to determine the type of contour to be detected. Three options are available, "dominant" (default), "fundamental" and "entropy". 
 #' @param wl A numeric vector of length 1 specifying the window length of the spectrogram, default 
 #'   is 512.
@@ -20,7 +19,7 @@
 #' @param ovlp Numeric vector of length 1 specifying \% of overlap between two 
 #'   consecutive windows, as in \code{\link[seewave]{spectro}}. Default is 70. 
 #' @param bp A numeric vector of length 2 for the lower and upper limits of a 
-#'   frequency bandpass filter (in kHz). Default is c(0, 22).
+#'   frequency bandpass filter (in kHz). Default is \code{NULL}.
 #' @param threshold amplitude threshold (\%) for fundamental frequency detection. Default is 15.
 #' @param img Logical argument. If \code{FALSE}, image files are not produced. Default is \code{TRUE}.
 #' @param parallel Numeric. Controls whether parallel computing is applied.
@@ -100,10 +99,7 @@
 #' @author Marcelo Araya-Salas (\email{marcelo.araya@@ucr.ac.cr})
 #last modification on mar-2021 (MAS)
 
-freq_ts <- function(X, type = "dominant", wl = 512, length.out = 20, wn = "hanning", ovlp = 70, bp = c(0, 22), threshold = 15, img = TRUE, parallel = 1, path = NULL, img.suffix = "frequency.ts", pb = TRUE, clip.edges = FALSE, leglab = "frequency.ts", track.harm = FALSE, raw.contour = FALSE, adjust.wl = TRUE, ff.method = "seewave", entropy.range = c(2, 10),...){     
-  
-  # set pb options 
-  on.exit(pbapply::pboptions(type = .Options$pboptions$type), add = TRUE)
+freq_ts <- function(X, type = "dominant", wl = 512, length.out = 20, wn = "hanning", ovlp = 70, bp = NULL, threshold = 15, img = TRUE, parallel = 1, path = NULL, img.suffix = "frequency.ts", pb = TRUE, clip.edges = FALSE, leglab = "frequency.ts", track.harm = FALSE, raw.contour = FALSE, adjust.wl = TRUE, ff.method = "seewave", entropy.range = c(2, 10),...){     
   
   #### set arguments from options
   # get function arguments
@@ -112,9 +108,6 @@ freq_ts <- function(X, type = "dominant", wl = 512, length.out = 20, wn = "hanni
   # get warbleR options
   opt.argms <- if(!is.null(getOption("warbleR"))) getOption("warbleR") else SILLYNAME <- 0
   
-  # rename path for sound files
-  names(opt.argms)[names(opt.argms) == "wav.path"] <- "path"
-  
   # remove options not as default in call and not in function arguments
   opt.argms <- opt.argms[!sapply(opt.argms, is.null) & names(opt.argms) %in% argms]
   
@@ -134,11 +127,11 @@ freq_ts <- function(X, type = "dominant", wl = 512, length.out = 20, wn = "hanni
     if (!dir.exists(path)) stop("'path' provided does not exist") else
       path <- normalizePath(path)
   
-    #if X is not a data frame
-    if (!any(is.data.frame(X), is_selection_table(X), is_extended_selection_table(X))) stop("X is not of a class 'data.frame', 'selection_table' or 'extended_selection_table'")
-    
+  #if X is not a data frame
+  if (!any(is.data.frame(X), is_selection_table(X), is_extended_selection_table(X))) stop("X is not of a class 'data.frame', 'selection_table' or 'extended_selection_table'")
+  
   if (!all(c("sound.files", "selec", 
-            "start", "end") %in% colnames(X))) 
+             "start", "end") %in% colnames(X))) 
     stop(paste(paste(c("sound.files", "selec", "start", "end")[!(c("sound.files", "selec", 
                                                                    "start", "end") %in% colnames(X))], collapse=", "), "column(s) not found in data frame"))
   
@@ -154,11 +147,19 @@ freq_ts <- function(X, type = "dominant", wl = 512, length.out = 20, wn = "hanni
   #if any selections longer than 20 secs stop
   if (any(X$end - X$start>20)) stop(paste(length(which(X$end - X$start>20)), "selection(s) longer than 20 sec"))  
   options( show.error.messages = TRUE)
-  
-  #if bp is not vector or length!=2 stop
-  if (!is.null(bp)) {if (!is.vector(bp)) stop("'bp' must be a numeric vector of length 2") else{
-    if (!length(bp) == 2) stop("'bp' must be a numeric vector of length 2")}}
 
+  # bp checking
+  if (!is.null(bp))
+  if (bp[1] != "frange")
+  {if (!is.vector(bp)) stop("'bp' must be a numeric vector of length 2 or 'frange'") else{
+    if (!length(bp) == 2) stop("'bp' must be a numeric vector of length 2 or 'frange'")} 
+  } else {
+    if (!any(names(X) == "bottom.freq") & !any(names(X) == "top.freq")) stop("'bp' = 'frange' requires bottom.freq and top.freq columns in X")
+    if (any(is.na(c(X$bottom.freq, X$top.freq)))) stop("NAs found in bottom.freq and/or top.freq") 
+    if (any(c(X$bottom.freq, X$top.freq) < 0)) stop("Negative values found in bottom.freq and/or top.freq") 
+    if (any(X$top.freq - X$bottom.freq < 0)) stop("top.freq should be higher than bottom.freq")
+  }
+    
   # if type argument  
   if (!any(type == "dominant", type == "fundamental", type == "entropy")) stop(paste("type", type, "is not recognized"))    
   
@@ -167,15 +168,15 @@ freq_ts <- function(X, type = "dominant", wl = 512, length.out = 20, wn = "hanni
   
   #return warning if not all sound files were found
   if (!is_extended_selection_table(X))
-  {recs.wd <- list.files(path = path, pattern = "\\.wav$", ignore.case = TRUE)
+  {recs.wd <- list.files(path = path, pattern = "\\.wav$|\\.wac$|\\.mp3$|\\.flac$", ignore.case = TRUE)
   if (length(unique(X$sound.files[(X$sound.files %in% recs.wd)])) != length(unique(X$sound.files)) & pb) 
     cat(paste(length(unique(X$sound.files))-length(unique(X$sound.files[(X$sound.files %in% recs.wd)])), 
-                  ".wav file(s) not found"))
+              "sound file(s) not found"))
   
   #count number of sound files in working directory and if 0 stop
   d <- which(X$sound.files %in% recs.wd) 
   if (length(d) == 0){
-    stop("The .wav files are not in the working directory")
+    stop("The sound files are not in the working directory")
   }  else X <- X[d, , drop = FALSE]
   }
   
@@ -190,18 +191,23 @@ freq_ts <- function(X, type = "dominant", wl = 512, length.out = 20, wn = "hanni
     contour_FUN <- function(X, i, bp, wl, threshold, entropy.range, raw.contour, track.harm, adjust.wl){
       
       # Read sound files to get sample rate and length
-      r <- warbleR::read_wave(X = X, path = path, index = i, header = TRUE)
+      r <- warbleR::read_sound_file(X = X, path = path, index = i, header = TRUE)
       f <- r$sample.rate
       
       # if bp is frange
+      if (!is.null(bp))
       if (bp[1] == "frange") bp <- c(X$bottom.freq[i], X$top.freq[i])
       
-      #in case bp its higher than can be due to sampling rate
       b <- bp 
-      if (!is.null(b)) {if (b[2] > ceiling(f/2000) - 1) b[2] <- ceiling(f/2000) - 1 
-      b <- b * 1000}
       
-      r <- warbleR::read_wave(X = X, path = path, index = i)
+      #in case bp its higher than can be due to sampling rate
+      if (!is.null(b)) {if (b[2] > floor(f/2000)) 
+        b[2] <- floor(f/2000) 
+        b <- b * 1000
+        }  
+      
+      
+      r <- warbleR::read_sound_file(X = X, path = path, index = i)
       
       # calculate dominant frequency at each time point     
       dfrq1 <- track_harmonic(wave = r, f = f, wl = wl, plot = FALSE, ovlp = ovlp, bandpass = b, fftw = TRUE,
@@ -293,173 +299,173 @@ freq_ts <- function(X, type = "dominant", wl = 512, length.out = 20, wn = "hanni
       if (img)  
       {
         warbleR::track_freq_contour(X = X[i, , drop = FALSE], wl = wl, osci = FALSE, leglab = leglab, pb = FALSE, wn = wn, bp = bp, 
-                            parallel = 1, path = path, img.suffix = img.suffix, ovlp = ovlp,
-                            custom.contour = cstm.cntr, frange.detec = FALSE, ...)
+                                    parallel = 1, path = path, img.suffix = img.suffix, ovlp = ovlp,
+                                    custom.contour = cstm.cntr, frange.detec = FALSE, ...)
       } 
       if (!raw.contour) return(t(apdom$y))  else return(dfrq)  
     } 
   
   if (type == "fundamental")
     contour_FUN <- function(X, i, bp, wl, threshold, entropy.range, raw.contour, track.harm, adjust.wl){
-    
-    # Read sound files to get sample rate and length
-    r <- warbleR::read_wave(X = X, path = path, index = i, header = TRUE)
-    f <- r$sample.rate
-    
-    b<- bp 
-    if (!is.null(b)) {if (b[2] > ceiling(f/2000) - 1) b[2] <- ceiling(f/2000) - 1 
-    b <- b * 1000}
-    
-    r <- warbleR::read_wave(X = X, path = path, index = i)
-    
-    # calculate fundamental frequency at each time point     
-    if (ff.method == "seewave")
-      ffreq1 <- seewave::fund(r, fmax= b[2], f = f, ovlp = ovlp, threshold = threshold, plot = FALSE) else
-      {
-        if (any(slotNames(r) == "stereo")) if (r@stereo) r <- mono(r, which = "both")
-        suppressWarnings(ff1 <- tuneR::FF(tuneR::periodogram(r, width = wl, overlap = wl*ovlp / 100), peakheight = (100 - threshold) / 100)/1000)
-        ff2 <- seq(0, X$end[i] - X$start[i], length.out = length(ff1))
-        
-        ffreq1 <- cbind(ff2, ff1)
-      }
-    
-    ffreq <- matrix(ffreq1[!is.na(ffreq1[,2]),], ncol = 2)  
-    ffreq <- matrix(ffreq[ffreq[,2] > b[1]/1000,], ncol = 2)
-
-    if (nrow(ffreq) < 2) {
-      apfund <- list()
-      apfund$x <- ffreq1[, 1]
-      apfund$y <- rep(NA, length.out)
-      apfund1 <- apfund
-    } else {
-      if (!clip.edges)  {
-        
-        # clip start edges
-        ffreq <- ffreq[which(as.numeric(is.na(ffreq[ , 2])) == 0)[1]:nrow(ffreq), ]
-        
-        # clip end edges
-        ffreq <- ffreq[1:max(which(as.numeric(is.na(ffreq[ , 2])) == 0)), ]
-        
-        # interpolate
-        apfund <- approx(ffreq[,1], ffreq[,2], xout = seq(from = ffreq1[1, 1],
-                                                          to = ffreq1[nrow(ffreq1), 1], length.out = length.out), 
-                         method = "linear") 
+      
+      # Read sound files to get sample rate and length
+      r <- warbleR::read_sound_file(X = X, path = path, index = i, header = TRUE)
+      f <- r$sample.rate
+      
+      b <- bp 
+      
+      if (!is.null(b)) {if (b[2] > floor(f/2000)) b[2] <- floor(f/2000) 
+      b <- b * 1000}
+      
+      r <- warbleR::read_sound_file(X = X, path = path, index = i)
+      
+      # calculate fundamental frequency at each time point     
+      if (ff.method == "seewave")
+        ffreq1 <- seewave::fund(r, fmax= b[2], f = f, ovlp = ovlp, threshold = threshold, plot = FALSE) else
+        {
+          if (any(slotNames(r) == "stereo")) if (r@stereo) r <- mono(r, which = "both")
+          suppressWarnings(ff1 <- tuneR::FF(tuneR::periodogram(r, width = wl, overlap = wl*ovlp / 100), peakheight = (100 - threshold) / 100)/1000)
+          ff2 <- seq(0, X$end[i] - X$start[i], length.out = length(ff1))
+          
+          ffreq1 <- cbind(ff2, ff1)
+        }
+      
+      ffreq <- matrix(ffreq1[!is.na(ffreq1[,2]),], ncol = 2)  
+      ffreq <- matrix(ffreq[ffreq[,2] > b[1]/1000,], ncol = 2)
+      
+      if (nrow(ffreq) < 2) {
+        apfund <- list()
+        apfund$x <- ffreq1[, 1]
+        apfund$y <- rep(NA, length.out)
         apfund1 <- apfund
       } else {
-        if (!raw.contour)
-        apfund <- approx(ffreq[,1], ffreq[,2], 
-                         xout = seq(from = ffreq[1, 1],  to = ffreq[nrow(ffreq), 1], 
-                                    length.out = length.out), method = "linear") else
-        
-          apfund <- ffreq
-        #fix for ploting with trackfreqs
-        #calculate time at start and end with no amplitude detected (duration of clipped edges)
-        durend1 <- suppressWarnings(diff(range(ffreq1[,1][rev(cumsum(rev(ffreq1[,2])) == 0)])))
-        durend <- durend1
-        if (is.infinite(durend) | is.na(durend)) durend <- 0
-        
-        durst1 <- suppressWarnings(diff(range(ffreq1[,1][cumsum(ffreq1[,2]) == 0])))   
-        durst <- durst1
-        if (is.infinite(durst) | is.na(durst)) durst <- 0
-        
-        by.dur <- mean(diff(apfund$x))
-        clipst <- length(seq(from = 0, to = durst, by = by.dur))
-        clipend <- length(seq(from = 0, to = durend, by = by.dur))
-        
-        apfund1 <- apfund
-        apfund1$y <- c(rep(NA, clipst) ,apfund$y, rep(NA, clipend))
-        
-        if (is.infinite(durst1) | is.na(durst1)) apfund1$y <- apfund1$y[-1]
-        if (is.infinite(durend1) | is.na(durend1)) apfund1$y <- apfund1$y[-length(apfund1$y)]
+        if (!clip.edges)  {
+          
+          # clip start edges
+          ffreq <- ffreq[which(as.numeric(is.na(ffreq[ , 2])) == 0)[1]:nrow(ffreq), ]
+          
+          # clip end edges
+          ffreq <- ffreq[1:max(which(as.numeric(is.na(ffreq[ , 2])) == 0)), ]
+          
+          # interpolate
+          apfund <- approx(ffreq[,1], ffreq[,2], xout = seq(from = ffreq1[1, 1],
+                                                            to = ffreq1[nrow(ffreq1), 1], length.out = length.out), 
+                           method = "linear") 
+          apfund1 <- apfund
+        } else {
+          if (!raw.contour)
+            apfund <- approx(ffreq[,1], ffreq[,2], 
+                             xout = seq(from = ffreq[1, 1],  to = ffreq[nrow(ffreq), 1], 
+                                        length.out = length.out), method = "linear") else
+                                          
+                                          apfund <- ffreq
+                                        #fix for ploting with trackfreqs
+                                        #calculate time at start and end with no amplitude detected (duration of clipped edges)
+                                        durend1 <- suppressWarnings(diff(range(ffreq1[,1][rev(cumsum(rev(ffreq1[,2])) == 0)])))
+                                        durend <- durend1
+                                        if (is.infinite(durend) | is.na(durend)) durend <- 0
+                                        
+                                        durst1 <- suppressWarnings(diff(range(ffreq1[,1][cumsum(ffreq1[,2]) == 0])))   
+                                        durst <- durst1
+                                        if (is.infinite(durst) | is.na(durst)) durst <- 0
+                                        
+                                        by.dur <- mean(diff(apfund$x))
+                                        clipst <- length(seq(from = 0, to = durst, by = by.dur))
+                                        clipend <- length(seq(from = 0, to = durend, by = by.dur))
+                                        
+                                        apfund1 <- apfund
+                                        apfund1$y <- c(rep(NA, clipst) ,apfund$y, rep(NA, clipend))
+                                        
+                                        if (is.infinite(durst1) | is.na(durst1)) apfund1$y <- apfund1$y[-1]
+                                        if (is.infinite(durend1) | is.na(durend1)) apfund1$y <- apfund1$y[-length(apfund1$y)]
+        }
       }
-    }
-    
-    if (img) 
-      warbleR::track_freq_contour(X[i, , drop = FALSE], wl = wl, osci = FALSE, leglab = leglab, pb = FALSE, wn = wn,
-                 parallel = 1, path = path, img.suffix =  img.suffix, ovlp = ovlp,
-                 custom.contour = data.frame(sound.files = X$sound.files[i], selec = X$selec[i], t(apfund$y)), ...)
-    
-    return(apfund$y)  
-  } 
+      
+      if (img) 
+        warbleR::track_freq_contour(X[i, , drop = FALSE], wl = wl, osci = FALSE, leglab = leglab, pb = FALSE, wn = wn,
+                                    parallel = 1, path = path, img.suffix =  img.suffix, ovlp = ovlp,
+                                    custom.contour = data.frame(sound.files = X$sound.files[i], selec = X$selec[i], t(apfund$y)), ...)
+      
+      return(apfund$y)  
+    } 
   
   if (type == "entropy")
     contour_FUN <- function(X, i, bp, wl, threshold, entropy.range, raw.contour, track.harm, adjust.wl){
-    
-    # Read sound files to get sample rate and length
-    r <- warbleR::read_wave(X = X, path = path, index = i, header = TRUE)
-    f <- r$sample.rate
-    
-    # if bp is frange
-    if (!is.null(bp))
-      if (bp[1] == "frange") bp <- c(X$bottom.freq[i], X$top.freq[i])
-    
-    #in case bp its higher than can be due to sampling rate
-    b<- bp 
-    if (!is.null(b)) {if (b[2] > ceiling(f/2000) - 1) b[2] <- ceiling(f/2000) - 1 
-    b <- b * 1000}
-    
-    r <- warbleR::read_wave(X = X, path = path, index = i)
-    
-    #filter if this was needed
-    if (!is.null(bp)) r <- ffilter(wave = r, from = b[1], to = b[2]) 
-    
-    # measure espectral entropy
-    sp.en <- csh(wave = r, f = f, wl = wl, ovlp = ovlp, wn = wn, 
-                 threshold = threshold, plot = F)
-    
-    if (clip.edges) 
-    {    #remove initial values with 0
-      sp.en1 <- sp.en[cumsum(sp.en[,2]) != 0, ]
       
-      #remove end values with 0
-      sp.en1 <- sp.en1[rev(cumsum(rev(sp.en1[,2])) != 0),]
+      # Read sound files to get sample rate and length
+      r <- warbleR::read_sound_file(X = X, path = path, index = i, header = TRUE)
+      f <- r$sample.rate
       
-    } else sp.en1 <- sp.en
-    
-    apen <- approx(sp.en1[,1], sp.en1[,2], xout = seq(from = sp.en1[1, 1],
-                                                      to = sp.en1[nrow(sp.en1), 1], length.out = length.out),
-                   method = "linear")  
-    
-    #fix for ploting with trackfreqs
-    if (clip.edges) 
-    { apen1 <- approx(sp.en[,1], sp.en[,2], xout = seq(from = sp.en[1, 1],
-                                                       to = sp.en[nrow(sp.en), 1], length.out = length.out),
-                      method = "linear")
-    
-    #make 0s at start and end NAs so they are plot at the bottom by trackfreqs
-    apen1$y[cumsum(apen1$y) == 0] <- NA
-    apen1$y[rev(cumsum(rev(apen1$y))) == 0] <- NA
-    }  else apen1 <- apen
-    
-    correc.apen <- entropy.range[1] + (entropy.range[2] - entropy.range[1]) * apen1$y 
-    
-    if (img) 
-      warbleR::track_freq_contour(X[i, , drop = FALSE], wl = wl, osci = FALSE, leglab = leglab, pb = FALSE, wn = wn,
-                          parallel = 1, path = path, img.suffix =  img.suffix, ovlp = ovlp,
-                          custom.contour = data.frame(sound.files = X$sound.files[i], selec = X$selec[i], t(correc.apen)), ...)
-    
-    
-    return(apen$y)  
-  } 
-  
-  
-  # set pb options 
-  pbapply::pboptions(type = ifelse(pb, "timer", "none"))
+      # if bp is frange
+      if (!is.null(bp))
+        if (bp[1] == "frange") bp <- c(X$bottom.freq[i], X$top.freq[i]) 
+      
+      #in case bp its higher than can be due to sampling rate
+      b <- bp 
+      if (!is.null(b)) {if (b[2] > floor(f/2000)) b[2] <- floor(f/2000) 
+      b <- b * 1000}
+      
+      r <- warbleR::read_sound_file(X = X, path = path, index = i)
+      
+      #filter if this was needed
+      if (!is.null(bp)) r <- ffilter(wave = r, from = b[1], to = b[2]) 
+      
+      # measure espectral entropy
+      sp.en <- csh(wave = r, f = f, wl = wl, ovlp = ovlp, wn = wn, 
+                   threshold = threshold, plot = F)
+      
+      if (clip.edges) 
+      {    #remove initial values with 0
+        sp.en1 <- sp.en[cumsum(sp.en[,2]) != 0, ]
+        
+        #remove end values with 0
+        sp.en1 <- sp.en1[rev(cumsum(rev(sp.en1[,2])) != 0),]
+        
+      } else sp.en1 <- sp.en
+      
+      apen <- approx(sp.en1[,1], sp.en1[,2], xout = seq(from = sp.en1[1, 1],
+                                                        to = sp.en1[nrow(sp.en1), 1], length.out = length.out),
+                     method = "linear")  
+      
+      #fix for ploting with trackfreqs
+      if (clip.edges) 
+      { apen1 <- approx(sp.en[,1], sp.en[,2], xout = seq(from = sp.en[1, 1],
+                                                         to = sp.en[nrow(sp.en), 1], length.out = length.out),
+                        method = "linear")
+      
+      #make 0s at start and end NAs so they are plot at the bottom by trackfreqs
+      apen1$y[cumsum(apen1$y) == 0] <- NA
+      apen1$y[rev(cumsum(rev(apen1$y))) == 0] <- NA
+      }  else apen1 <- apen
+      
+      correc.apen <- entropy.range[1] + (entropy.range[2] - entropy.range[1]) * apen1$y 
+      
+      if (img) 
+        warbleR::track_freq_contour(X[i, , drop = FALSE], wl = wl, osci = FALSE, leglab = leglab, pb = FALSE, wn = wn,
+                                    parallel = 1, path = path, img.suffix =  img.suffix, ovlp = ovlp,
+                                    custom.contour = data.frame(sound.files = X$sound.files[i], selec = X$selec[i], t(correc.apen)), ...)
+      
+      
+      return(apen$y)  
+    } 
   
   # set clusters for windows OS
   if (Sys.info()[1] == "Windows" & parallel > 1)
     cl <- parallel::makePSOCKcluster(getOption("cl.cores", parallel)) else cl <- parallel
   
   # run loop apply function
-  lst <- pbapply::pblapply(X = 1:nrow(X), cl = cl, FUN = function(i) 
+  lst <- pblapply_wrblr_int(pbar = pb, X = 1:nrow(X), cl = cl, FUN = function(i) 
   { 
     contour_FUN(X, i, bp, wl, threshold, entropy.range, raw.contour, track.harm, adjust.wl)
   })
   
+  #
   df <- data.frame(sound.files = X$sound.files, selec = X$selec, as.data.frame(matrix(unlist(lst),nrow = length(X$sound.files), byrow = TRUE)))
-  colnames(df)[3:ncol(df)]<-paste("ffreq",1:(ncol(df)-2),sep = "-")
+  
+  colnames(df)[3:ncol(df)] <- paste("ffreq",1:(ncol(df)-2),sep = "-")
+  
   df[ ,3:ncol(df)] <- round(df[ ,3:ncol(df)], 3)
-   
+  
   return(df)
   
 }
